@@ -713,7 +713,7 @@ class GoesRPUGImporter(aSingleFileWithSingleProductImporter):
         is_netcdf = (fn.lower().endswith('.nc') or fn.lower().endswith('.nc4'))
         if not is_netcdf:
             raise ValueError("PUG loader requires files ending in .nc or .nc4: {}".format(repr(source_path)))
-        return PugFile.attach(source_path)
+        return PugFile.attach(source_path)  # noqa
         # if 'L1b' in fn:
         #     LOG.debug('attaching {} as PUG L1b'.format(source_path))
         #     return PugL1bTools(source_path)
@@ -1070,7 +1070,7 @@ class SatpyImporter(aImporter):
             ds.attrs.setdefault(Info.STANDARD_NAME, ds.attrs.get('standard_name'))
             if 'wavelength' in ds.attrs:
                 ds.attrs.setdefault(Info.CENTRAL_WAVELENGTH,
-                                    ds.attrs['wavelength'][0])
+                                    ds.attrs['wavelength'][1])
 
             # Resolve anything else needed by SIFT
             id_str = ":".join(str(v) for v in DatasetID.from_dict(ds.attrs))
@@ -1168,8 +1168,13 @@ class SatpyImporter(aImporter):
             antimeridian = 179.999
             if '+proj=latlong' not in proj4:
                 # the x coordinate for the antimeridian in this projection
-                antimeridian = Proj(proj4)(antimeridian, 0)[0]
-            am_index = int(np.ceil((antimeridian - origin_x) / cell_width))
+                am = Proj(proj4)(antimeridian, 0)[0]
+                if am < 1e30:
+                    am_index = -1
+                else:
+                    am_index = int(np.ceil((antimeridian - origin_x) / cell_width))
+            else:
+                am_index = int(np.ceil((antimeridian - origin_x) / cell_width))
             if prod.info[Info.KIND] == Kind.CONTOUR and 0 < am_index < shape[1]:
                 # if we have data from 0 to 360 longitude, we want -180 to 360
                 data = da.concatenate((data[:, am_index:], data), axis=1)
